@@ -11,11 +11,12 @@ from collections import abc, OrderedDict
 from types import SimpleNamespace
 import warnings
 import copyreg
+import re
 import numpy as np
 import pandas as pd
 import xlsxwriter
 from pyyeti.nastran import n2p
-from ._utilities import _merge_uf_reds, _is_valid_identifier, get_drfunc
+from ._utilities import _merge_uf_reds, _is_valid_identifier, _compile_strfunc
 
 
 # FIXME: We need the str/repr formatting used in Numpy < 1.14.
@@ -214,28 +215,46 @@ class DR_Def(OrderedDict):
                 curdrms[se] = {}
             _add_drms(curdrms[se], newdrms)
 
-    def _check_for_drfunc(self, filename, funcname):
+    def _check_for_drfunc(self, name, filename, funcname):
         def _get_msg():
-            s0 = f'When checking for the data recovery function "{funcname}",'
+            s0 = f'When checking `drfunc` for category "{name}",'
             s1 = (
                 "This can be safely ignored if you plan to "
                 "implement the data recovery functions later."
             )
             return s0, s1
 
-        try:
-            get_drfunc(filename, funcname)
-        except (FileNotFoundError, ImportError, SyntaxError) as e:
-            s0, s1 = _get_msg()
-            msg = (
-                f'{s0} import of "{filename}" failed. {s1}\nThe exception was: '
-                f"{type(e).__name__}: {e!s}"
-            )
-            warnings.warn(msg, RuntimeWarning)
-        except AttributeError:
-            s0, s1 = _get_msg()
-            msg = f'{s0} "{funcname}" not found in: {filename}. {s1}'
-            warnings.warn(msg, RuntimeWarning)
+        if _is_valid_identifier(funcname):
+            try:
+                # search for "def funcname("
+                with open(filename, "r") as fin:
+                    for line in fin:
+                        if re.match(rf" *def +{funcname} *\(", line):
+                            break
+                    else:
+                        s0, s1 = _get_msg()
+                        msg = (
+                            f'{s0} function "{funcname}" not found in: '
+                            f"{filename}. {s1}"
+                        )
+                        warnings.warn(msg, RuntimeWarning)
+            except FileNotFoundError as e:
+                s0, s1 = _get_msg()
+                msg = (
+                    f'{s0} could not open "{filename}". {s1}\nThe exception was: '
+                    f"{type(e).__name__}: {e!s}"
+                )
+                warnings.warn(msg, RuntimeWarning)
+        else:
+            try:
+                _compile_strfunc(funcname, False)
+            except SyntaxError as e:
+                s0, s1 = _get_msg()
+                msg = (
+                    f'{s0} failed to compile string: "{funcname}".\n'
+                    f"The exception was: {type(e).__name__}: {e!s}"
+                )
+                warnings.warn(msg, RuntimeWarning)
 
     @staticmethod
     def _get_pv(pv, name, length):
@@ -327,7 +346,8 @@ class DR_Def(OrderedDict):
                     callerdir = os.path.dirname(calling_file)
                     ns.drfile = os.path.join(callerdir, drfile)
                 self._drfilemap[drfile] = ns.drfile
-            self._check_for_drfunc(ns.drfile, ns.drfunc)
+
+        self._check_for_drfunc(name, ns.drfile, ns.drfunc)
 
         # ensure uf_reds has no None values:
         ns.uf_reds = _merge_uf_reds((1, 1, 1, 1), ns.uf_reds)
@@ -354,16 +374,16 @@ class DR_Def(OrderedDict):
 
         ns.ignorepv = self._get_pv(ns.ignorepv, "ignorepv", len(ns.labels))
 
-        if ns.srsconv is None and ns.srsQs is not None:
-            ns.srsconv = 1.0
-
         if ns.srsQs is not None:
             ns.srsQs = n2p._ensure_iter(ns.srsQs)
             if ns.srspv is None:
                 ns.srspv = slice(len(ns.labels))
 
+        if ns.srsconv is None and ns.srsQs is not None:
+            ns.srsconv = self.defaults.get("srsconv", 1.0)
+
         if ns.srspv is not None and ns.srsopts is None:
-            ns.srsopts = {}
+            ns.srsopts = self.defaults.get("srsopts", {})
 
         # fill in hist-labels/units and srs-labels/units if needed:
         for i in ("hist", "srs"):
@@ -532,7 +552,7 @@ class DR_Def(OrderedDict):
 
             DA: if `drfile` is set in `self.defaults`, that is used;
             otherwise, it is set to the full name of the file that
-            called this routine (as if it was input as '.').
+            called this routine (as if `drfile` was input as '.').
         se : integer or None; optional
             The superelement number.
 
@@ -613,20 +633,33 @@ class DR_Def(OrderedDict):
             Conversion factor for the SRS; scalar or vector same
             length as `srspv`.
 
-            DA: it is internally reset to 1.0 if `srsQs` is not None
-            (after its default action, if applicable); otherwise,
-            leave it None.
+            DA: if `srsQs` is not None (after its default action, if
+            applicable), either get value for `srsconv` from
+            `self.defaults` (if possible), or set to 1.0. If
+            `srsQs` is None, leave `srsconv` None.
         srslabels : list_like or None; optional
             Analogous to `labels` but just for the `srspv` rows.
 
             DA: derive from `labels` according to `srspv` if needed;
             otherwise, leave it None.
         srsopts : dict or None; optional
-            Dictionary of options for SRS; eg:
-            ``dict(eqsine=True, ic='steady')``
+            This dictionary can specify options for all three of these
+            SRS calculation routines: :func:`pyyeti.srs.srs`,
+            :func:`pyyeti.srs.srs_frf`, and
+            :func:`pyyeti.srs.vrs`. The "eqsine" option is special in
+            that it enforces equivalent sine output for all three
+            routines even if the routine does not accept "eqsine" as
+            input. Other options are only passed if the function
+            accepts it. For example, to specify equivalent sine for
+            all three ("eqsine" is special, as noted), steady-state
+            initial conditions for :func:`pyyeti.srs.srs` and
+            `scale_by_Q_only` for :func:`pyyeti.srs.srs_frf`, use:
+            ``dict(eqsine=True, ic='steady', scale_by_Q_only=True)``
 
-            DA: set to ``{}`` if `srspv` is not None; otherwise, leave
-            it None.
+            DA: if `srsQs` is not None (after its default action, if
+            applicable), either get value for `srsopts` from
+            `self.defaults` (if possible), or set to ``{}``. If
+            `srsQs` is None, leave `srsopts` None.
         srspv : 1d array_like or 'all' or slice or None; optional
             Specifies which rows to compute SRS for. See note below
             about inputting partition vectors.
